@@ -1,7 +1,6 @@
 """ Model for Topogrpahic features """
 import logging
 
-import numpy as np
 from nowcasting_dataset.consts import TOPOGRAPHIC_DATA
 from pydantic import Field, validator
 
@@ -59,25 +58,6 @@ class TopographicML(DataSourceOutputML):
         assert v.shape[-1] == values["topo_data"].shape[-1]
         return v
 
-    @staticmethod
-    def fake(batch_size, image_size_pixels):
-        """Create fake data"""
-        return TopographicML(
-            batch_size=batch_size,
-            topo_data=np.random.randn(
-                batch_size,
-                image_size_pixels,
-                image_size_pixels,
-            ).astype(np.float32),
-            topo_x_coords=np.sort(
-                np.random.randn(batch_size, image_size_pixels).astype(np.float32)
-            ),
-            topo_y_coords=np.sort(
-                np.random.randn(batch_size, image_size_pixels).astype(np.float32)
-            )[:, ::-1].copy(),
-            # copy is needed as torch doesnt not support negative strides
-        )
-
     @staticmethod
     def from_xr_dataset(xr_dataset):
         """Change xr dataset to model. If data does not exist, then return None"""
